OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Denegado (permiso heredado)",
    "Allowed (Inherited permission)" : "Permitido (permiso heredado)",
    "Denied" : "Denegado",
    "Allowed" : "Permitido",
    "Access denied" : "Acceso denegado",
    "Access allowed" : "Acceso permitido",
    "Inherit permission" : "Heredar permisos",
    "Deny" : "Denegar",
    "Allow" : "Permitir",
    "Group" : "Grupo",
    "Team" : "Equipo",
    "Read" : "Leer",
    "Write" : "Escribir",
    "Create" : "Crear",
    "Delete" : "Borrar",
    "Share" : "Compartir",
    "You" : "Tú",
    "Remove access rule" : "Eliminar regla de acceso",
    "Select a user or group" : "Seleccionar un usuario o grupo",
    "Permission denied. User does not have sufficient permissions." : "Permiso denegado. El usuario no cuenta con los permisos suficientes.",
    "Unexpected status from server" : "Estado inesperado del servidor",
    "Add group" : "Agregar grupo",
    "Default" : "Por omisión",
    "Unlimited" : "Ilimitado",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "¿Está seguro de que desea eliminar \"{folderName}\" y todos los archivos que contiene? Esta operación no se puede deshacer",
    "Delete \"{folderName}\"?" : "Borrar \"{folderName}\"?",
    "Group or team" : "Grupo o equipo",
    "Folder name" : "Nombre de la carpeta",
    "Quota" : "Cuota",
    "Advanced Permissions" : "Permisos avanzados",
    "Previous" : "Previo",
    "User" : "Usuario",
    "Unknown" : "Desconocido",
    "None" : "Ninguno",
    "{size} used" : "{size} usado",
    "Other …" : "Otro ...",
    "Unset" : "Desestablecer"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
